@@ -1,13 +1,23 @@
 # -*- coding: utf-8 -*-
 '''
-This module provides utilities for working with :term:`URIS <URI>`.
+This module provides utilities for working with :term:`URIs <URI>`.
 
 .. versionadded:: 0.3.0
 '''
 
-from __future__ import unicode_literals
-
 import abc
+import rfc3987
+
+def is_uri(uri):
+    '''
+    Check if a string is a valid URI according to rfc3987
+
+    :param string uri:
+    :rtype: boolean
+    '''
+    if uri is None:
+        return False
+    return rfc3987.match(uri, rule='URI')
 
 
 class UriGenerator(object):
@@ -71,7 +81,7 @@ class DefaultConceptSchemeUrnGenerator(UriGenerator):
     '''
     Generate a :term:`URN` for a conceptscheme specific to skosprovider.
 
-    Used for generating default :term:`URI <URIS>` for providers that do 
+    Used for generating default :term:`URI <URIS>` for providers that do
     not have an explicit conceptscheme.
     '''
 
